@@ -32,16 +32,16 @@ class SystemModel : public AbstractModel
         explicit SystemModel(QObject *parent = 0);
         ~SystemModel();
 
-        QString description() const Q_DECL_OVERRIDE;
+        QString description() const override;
 
-        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+        QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-        int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+        int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-        Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument) Q_DECL_OVERRIDE;
+        Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument) override;
 
     protected Q_SLOTS:
-        void refresh() Q_DECL_OVERRIDE;
+        void refresh() override;
 
     private:
         void init();
