@@ -26,10 +26,10 @@ class CfgEmailClient: public QWidget, public Ui::EmailClientConfig_UI, public Cf
     Q_OBJECT
 public:
     CfgEmailClient(QWidget *parent);
-    virtual ~CfgEmailClient();
-    void load(KConfig *cfg) Q_DECL_OVERRIDE;
-    void save(KConfig *cfg) Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    ~CfgEmailClient() override;
+    void load(KConfig *cfg) override;
+    void save(KConfig *cfg) override;
+    void defaults() override;
 
 private:
     KEMailSettings *pSettings;
