@@ -19,25 +19,48 @@
 #ifndef PREVIEWWIDGET_H
 #define PREVIEWWIDGET_H
 
-#include <QWidget>
+#include <QQuickPaintedItem>
+#include <QPointer>
+#include "sortproxymodel.h"
 
 class CursorTheme;
 class PreviewCursor;
 
-class PreviewWidget : public QWidget
+class PreviewWidget : public QQuickPaintedItem
 {
+    Q_OBJECT
+    Q_PROPERTY(SortProxyModel *themeModel READ themeModel WRITE setThemeModel NOTIFY themeModelChanged)
+    Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex NOTIFY currentIndexChanged)
+    Q_PROPERTY(int currentSize READ currentSize WRITE setCurrentSize NOTIFY currentSizeChanged)
+
+
     public:
-        PreviewWidget(QWidget *parent);
+        PreviewWidget(QQuickItem *parent = 0);
         ~PreviewWidget();
 
         void setTheme(const CursorTheme *theme, const int size);
         void setUseLables(bool);
-        QSize sizeHint() const Q_DECL_OVERRIDE;
+        void updateImplicitSize();
+
+        void setThemeModel(SortProxyModel *themeModel);
+        SortProxyModel *themeModel();
+
+        void setCurrentIndex(int idx);
+        int currentIndex() const;
+
+        void setCurrentSize(int size);
+        int currentSize() const;
+
+    Q_SIGNALS:
+        void themeModelChanged();
+        void currentIndexChanged();
+        void currentSizeChanged();
 
     protected:
-        void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
-        void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-        void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
+        void paint(QPainter *);
+        void hoverMoveEvent(QHoverEvent *event);
+        void hoverLeaveEvent(QHoverEvent *e);
+        void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
 
     private:
         void layoutItems();
@@ -45,6 +68,9 @@ class PreviewWidget : public QWidget
         QList<PreviewCursor*> list;
         const PreviewCursor *current;
         bool needLayout:1;
+        QPointer<SortProxyModel> m_themeModel;
+        int m_currentIndex;
+        int m_currentSize;
 };
 
 #endif // PREVIEWWIDGET_H
