@@ -50,6 +50,15 @@ CursorThemeModel::~CursorThemeModel()
    list.clear();
 }
 
+QHash<int, QByteArray> CursorThemeModel::roleNames() const
+{
+    QHash<int, QByteArray> roleNames = QAbstractTableModel::roleNames();
+    roleNames[CursorTheme::DisplayDetailRole] = "description";
+    roleNames[CursorTheme::IsWritableRole] = "isWritable";
+
+    return roleNames;
+}
+
 void CursorThemeModel::refreshList()
 {
     beginResetModel();
@@ -115,6 +124,10 @@ QVariant CursorThemeModel::data(const QModelIndex &index, int role) const
     if (role == Qt::DecorationRole && index.column() == NameColumn)
         return theme->icon();
 
+    if (role == CursorTheme::IsWritableRole) {
+        return theme->isWritable();
+    }
+
     return QVariant();
 }
 
@@ -195,7 +208,7 @@ const QStringList CursorThemeModel::searchPaths()
     }
 
     // Expand all occurrences of ~/ to the home dir
-    baseDirs.replaceInStrings(QRegExp(QStringLiteral("^~\\/")), QDir::home().path() + '/');
+    baseDirs.replaceInStrings(QRegExp("^~\\/"), QDir::home().path() + '/');
     return baseDirs;
 }
 
