@@ -21,8 +21,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 
-#include <QGuiApplication>
-#include <QScreen>
 #include <QCursor>
 #include <QImage>
 #include <QDir>
@@ -31,7 +29,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xcursor/Xcursor.h>
 
-#include <KWindowSystem/fixx11h.h>
 #include "xcursortheme.h"
 
 
@@ -152,14 +149,11 @@ XcursorImages *XCursorTheme::xcLoadImages(const QString &image, int size) const
 }
 
 
-int XCursorTheme::autodetectCursorSize() const
+int XCursorTheme::defaultCursorSize() const
 {
+    //TODO: manage Wayland
     if (!QX11Info::isPlatformX11()) {
-        if (QScreen *s = QGuiApplication::primaryScreen()) {
-            return s->logicalDotsPerInchY() * 16 / 72;
-        }
-        // some default value
-        return 16;
+        return 32;
     }
     /* This code is basically borrowed from display.c of the XCursor library
        We can't use "int XcursorGetDefaultSize(Display *dpy)" because if
@@ -191,8 +185,12 @@ int XCursorTheme::autodetectCursorSize() const
 
 qulonglong XCursorTheme::loadCursor(const QString &name, int size) const
 {
+    //TODO: manage Wayland
+    if (!QX11Info::isPlatformX11()) {
+        return None;
+    }
     if (size <= 0)
-        size = autodetectCursorSize();
+        size = defaultCursorSize();
 
     // Load the cursor images
     XcursorImages *images = xcLoadImages(name, size);
@@ -215,7 +213,7 @@ qulonglong XCursorTheme::loadCursor(const QString &name, int size) const
 QImage XCursorTheme::loadImage(const QString &name, int size) const
 {
     if (size <= 0)
-        size = autodetectCursorSize();
+        size = defaultCursorSize();
 
     // Load the image
     XcursorImage *xcimage = xcLoadImage(name, size);
