@@ -20,9 +20,9 @@
 #ifndef FLAGS_H_
 #define FLAGS_H_
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QMap>
+#include <QObject>
+#include <QString>
+#include <QMap>
 
 class QPixmap;
 class QIcon;
@@ -40,7 +40,7 @@ class Flags : public QObject
 
 public:
 	Flags();
-	virtual ~Flags();
+	~Flags() override;
 
 	const QIcon getIcon(const QString& layout);
 	const QIcon getIconWithText(const LayoutUnit& layoutUnit, const KeyboardConfig& keyboardConfig);
