@@ -21,8 +21,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#include <QtDBus/QDBusConnection>
-#include <QtCore/QTimer>
+#include <QDBusConnection>
+#include <QTimer>
 #include <QDebug>
 #include <kauth.h>
 #include <kio/global.h>
