@@ -40,7 +40,7 @@ class DevicePreference : public QWidget, private Ui::DevicePreference
     Q_OBJECT
 public:
     explicit DevicePreference(QWidget *parent = 0);
-    virtual ~DevicePreference();
+    ~DevicePreference() override;
 
     void load();
     void save();
@@ -51,7 +51,7 @@ Q_SIGNALS:
     void changed();
 
 protected:
-    void changeEvent(QEvent *) Q_DECL_OVERRIDE;
+    void changeEvent(QEvent *) override;
 
 private Q_SLOTS:
     void on_preferButton_clicked();
