@@ -24,14 +24,10 @@
 #include <QDBusConnectionInterface>
 #include <KNotification>
 #include <KLocalizedString>
-#include <KPluginFactory>
 
+#include "plugins.h"
 #include "kdedactions.h"
 
-K_PLUGIN_FACTORY_WITH_JSON(TouchpadDisablerFactory,
-                           "kded_touchpad.json",
-                           registerPlugin<TouchpadDisabler>();)
-
 bool TouchpadDisabler::workingTouchpadFound() const
 {
     return m_workingTouchpadFound;
@@ -75,7 +71,6 @@ TouchpadDisabler::TouchpadDisabler(QObject *parent, const QVariantList &)
     connect(&m_keyboardActivityTimeout, SIGNAL(timeout()),
             SLOT(timerElapsed()));
 
-
     updateCurrentState();
     m_userRequestedState = m_touchpadEnabled;
     reloadSettings();
@@ -306,5 +301,3 @@ void TouchpadDisabler::showOsd()
 
     QDBusConnection::sessionBus().asyncCall(msg);
 }
-
-#include "kded.moc"
