@@ -28,7 +28,7 @@ class KNetAttach : public QWizard, private Ui_KNetAttach
     Q_OBJECT
 
 public:
-    explicit KNetAttach( QWidget* parent = 0 );
+    explicit KNetAttach( QWidget* parent = nullptr );
 
 public slots:
     virtual void setInformationText( const QString & type );
@@ -41,7 +41,7 @@ private:
 
 private slots:
     void updateParametersPageStatus();
-    bool validateCurrentPage() Q_DECL_OVERRIDE;
+    bool validateCurrentPage() override;
     void updatePort( bool encryption );
     void updateFinishButtonText( bool save );
     void slotHelpClicked();
